"""Tests for alternation exercises"""
import unittest


from alternation import (
    is_number,
    abbreviate,
    is_hex_color,
    is_valid_date,
)


class AbbreviateTests(unittest.TestCase):

    """Tests for abbreviate."""

    def test_gif(self):
        self.assertEqual(abbreviate('Graphics Interchange Format'), 'GIF')

    def test_faq(self):
        self.assertEqual(abbreviate('frequently asked questions'), 'FAQ')

    def test_css(self):
        self.assertEqual(abbreviate('cascading style sheets'), 'CSS')

    def test_cms(self):
        self.assertEqual(abbreviate('content management system'), 'CMS')

    def test_json(self):
        self.assertEqual(abbreviate('JavaScript Object Notation'), 'JSON')

    def test_html(self):
        self.assertEqual(abbreviate('HyperText Markup Language'), 'HTML')


class IsNumberTests(unittest.TestCase):

    """Tests for is_number."""

    def test_5(self):
        self.assertTrue(is_number("5"))

    def test_5_point(self):
        self.assertTrue(is_number("5."))

    def test_point_5_point(self):
        self.assertFalse(is_number(".5."))

    def test_point_5(self):
        self.assertTrue(is_number(".5"))

    def test_leading_zero(self):
        self.assertTrue(is_number("01.5"))

    def test_negative(self):
        self.assertTrue(is_number("-123.859"))

    def test_two_decimals(self):
        self.assertFalse(is_number("-123.859."))

    def test_just_a_decimal(self):
        self.assertFalse(is_number("."))

    def test_leading_garbage(self):
        self.assertFalse(is_number("a5"))

    def test_trailing_garbage(self):
        self.assertFalse(is_number("5a"))


class IsHexColorTests(unittest.TestCase):

    """Tests for is_hex_color."""

    def test_purple_short(self):
        self.assertTrue(is_hex_color("#639"))

    def test_four_digits(self):
        self.assertFalse(is_hex_color("#6349"))

    def test_five_digits(self):
        self.assertFalse(is_hex_color("#63459"))

    def test_dark_purple(self):
        self.assertTrue(is_hex_color("#634569"))

    def test_purple_long(self):
        self.assertTrue(is_hex_color("#663399"))

    def test_black(self):
        self.assertTrue(is_hex_color("#000000"))

    def test_two_digits(self):
        self.assertFalse(is_hex_color("#00"))

    def test_mixed_case(self):
        self.assertTrue(is_hex_color("#FFffFF"))

    def test_hex(self):
        self.assertTrue(is_hex_color("#decaff"))

    def test_invalid_character(self):
        self.assertFalse(is_hex_color("#decafz"))

    def test_no_octothorpe(self):
        self.assertFalse(is_hex_color("639"))

    def test_misplaced_octothorpe(self):
        self.assertFalse(is_hex_color("639#"))

    def test_leading_garbage(self):
        self.assertFalse(is_hex_color("a#639"))


class IsValidDateTests(unittest.TestCase):

    """Tests for is_valid_date."""

    def test_this_year(self):
        self.assertTrue(is_valid_date("2016-01-02"))

    def test_1990(self):
        self.assertTrue(is_valid_date("1900-01-01"))

    def test_invalid_day(self):
        self.assertFalse(is_valid_date("2016-02-99"))

    def test_invalid_year(self):
        self.assertFalse(is_valid_date("20-02-20"))

    def test_invalid_month(self):
        self.assertFalse(is_valid_date("1980-30-05"))

    def test_leading_garbage(self):
        self.assertFalse(is_valid_date("12016-01-02"))

    def test_trailing_garbage(self):
        self.assertFalse(is_valid_date("2016-01-020"))


if __name__ == "__main__":
    raise SystemExit("No CLI for this file.  Run test.py instead.")
