"""Tests for validation exercises"""
import unittest


from intro import (
    has_vowel,
    is_integer,
    is_fraction,
)


class HasVowelTests(unittest.TestCase):

    """Tests for has_vowel."""

    def test_rhythm(self):
        self.assertFalse(has_vowel("rhythm"))

    def test_exit(self):
        self.assertTrue(has_vowel("exit"))

    def test_no(self):
        self.assertTrue(has_vowel("no"))

    def test_yes(self):
        self.assertTrue(has_vowel("yes"))

    def test_fly(self):
        self.assertFalse(has_vowel("fly"))

    def test_symbols(self):
        self.assertFalse(has_vowel("%^&"))

    def test_empty(self):
        self.assertFalse(has_vowel(""))


class IsIntegerTests(unittest.TestCase):

    """Tests for is_integer."""

    def test_single_digit(self):
        self.assertTrue(is_integer("5"))

    def test_leading_letter(self):
        self.assertFalse(is_integer("a5"))

    def test_trailing_letter(self):
        self.assertFalse(is_integer("5a"))

    def test_5000(self):
        self.assertTrue(is_integer("5000"))

    def test_leading_minus(self):
        self.assertTrue(is_integer("-999"))

    def test_leading_plus(self):
        self.assertFalse(is_integer("+999"))

    def test_leading_zero(self):
        self.assertTrue(is_integer("00"))

    def test_zero_decimal(self):
        self.assertFalse(is_integer("0.0"))

    def test_only_minus(self):
        self.assertFalse(is_integer("-"))

    def test_leading_space(self):
        self.assertFalse(is_integer(" 5"))

    def test_empty(self):
        self.assertFalse(is_integer(""))


class IsFractionTests(unittest.TestCase):

    """Tests for is_fraction."""

    def test_5000(self):
        self.assertFalse(is_fraction("5000"))

    def test_leading_minus(self):
        self.assertTrue(is_fraction("-999/1"))

    def test_leading_plus(self):
        self.assertFalse(is_fraction("+999/1"))

    def test_leading_zero_in_numerator(self):
        self.assertTrue(is_fraction("00/1"))

    def test_no_numerator(self):
        self.assertFalse(is_fraction("/5"))

    def test_no_denominator(self):
        self.assertFalse(is_fraction("5/"))

    def test_divide_by_zero(self):
        self.assertFalse(is_fraction("5/0"))

    def test_leading_zero_in_denominator(self):
        self.assertTrue(is_fraction("5/010"))

    def test_simple_fraction(self):
        self.assertTrue(is_fraction("5/105"))

    def test_with_spaces(self):
        self.assertFalse(is_fraction("5 / 1"))

    def test_empty(self):
        self.assertFalse(is_fraction(""))

    def test_leading_letter(self):
        self.assertFalse(is_fraction("a5"))

    def test_trailing_letter(self):
        self.assertFalse(is_fraction("5a"))


if __name__ == "__main__":
    raise SystemExit("No CLI for this file.  Run test.py instead.")
